import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _returnValue, _handleNativeClose, _dispatchCloseEvent, _dispatchShowEvent, _dispatchUiStateEvent, _handleTriggerSlotChange, handleTriggerSlotChange_fn, _handleTriggerClick;
import { localized, msg } from "@lit/localize";
import { property, query } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { GdsElement } from "../../gds-element.js";
import { watch } from "../../utils/decorators/watch.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import { GdsButton } from "../button/button.component.js";
import { GdsCard } from "../card/card.component.js";
import { GdsFlex } from "../flex/flex.component.js";
import { IconCrossLarge } from "../icon/icons/cross-large.component.js";
import { styles } from "./dialog.styles.js";
import {
  lockBodyScrolling,
  registerGlobalScrollLockStyles,
  unlockBodyScrolling
} from "./scroll-lock.js";
registerGlobalScrollLockStyles();
let GdsDialog = class extends GdsElement {
  constructor() {
    super(...arguments);
    __privateAdd(this, _handleTriggerSlotChange);
    this.open = false;
    this.variant = "default";
    __privateAdd(this, _returnValue, void 0);
    __privateAdd(this, _handleNativeClose, (e) => {
      const dialog = e.target;
      const returnValue = dialog.returnValue;
      this.close(returnValue || "native-close");
      if (returnValue !== "prop-change")
        __privateGet(this, _dispatchCloseEvent).call(this, returnValue);
    });
    __privateAdd(this, _dispatchCloseEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-close", {
          detail: reason,
          bubbles: false,
          composed: false
        })
      );
      __privateGet(this, _dispatchUiStateEvent).call(this, reason);
    });
    __privateAdd(this, _dispatchShowEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-show", {
          detail: reason,
          bubbles: false,
          composed: false
        })
      );
      __privateGet(this, _dispatchUiStateEvent).call(this, reason);
    });
    __privateAdd(this, _dispatchUiStateEvent, (reason) => {
      this.dispatchEvent(
        new CustomEvent("gds-ui-state", {
          detail: { reason, open: this.open },
          bubbles: false,
          composed: false
        })
      );
    });
    __privateAdd(this, _handleTriggerClick, (e) => {
      this.show("slotted-trigger");
    });
  }
  /**
   * Opens the dialog.
   */
  show(reason) {
    this.open = true;
    reason && __privateGet(this, _dispatchShowEvent).call(this, reason);
  }
  /**
   * Closes the dialog.
   * @param returnValue - The value to return when the dialog is closed.
   */
  close(reason) {
    __privateSet(this, _returnValue, reason);
    this.open = false;
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    unlockBodyScrolling(this);
  }
  render() {
    return html`<slot
        name="trigger"
        @slotchange=${__privateMethod(this, _handleTriggerSlotChange, handleTriggerSlotChange_fn)}
      ></slot>
      ${when(
      this.open,
      () => html`<dialog
            @close=${__privateGet(this, _handleNativeClose)}
            class=${this.variant}
            aria-describedby="heading"
          >
            <gds-card
              class="card"
              display="flex"
              variant="secondary"
              shadow="xl"
              padding="s"
              border-radius=${this.variant === "default" ? "s" : "0"}
            >
              <gds-flex
                justify-content="space-between"
                border-width="0 0 4xs 0"
                margin="0 -s"
                padding="0 s s"
                background-color="secondary"
              >
                <h2 id="heading">${this.heading}</h2>
                <gds-button
                  id="close-btn"
                  rank="secondary"
                  size="small"
                  label=${msg("Close")}
                  @click=${() => this.close("btn-close")}
                  ><gds-icon-cross-large></gds-icon-cross-large
                ></gds-button>
              </gds-flex>
              <gds-div id="content" padding="m 0" overflow="auto" flex="1">
                <slot></slot>
              </gds-div>
              <gds-flex
                class="footer"
                justify-content="center"
                gap="s"
                padding="s 0 0 0"
              >
                <slot name="footer">
                  <gds-button
                    value="cancel"
                    @click=${() => this.close("btn-cancel")}
                    rank="secondary"
                    >${msg("Cancel")}</gds-button
                  >
                  <gds-button value="ok" @click=${() => this.close("btn-ok")}
                    >Ok</gds-button
                  >
                </slot>
              </gds-flex>
            </gds-card>
          </dialog>`
    )}`;
  }
  _handleOpenChange() {
    if (this.open) {
      __privateSet(this, _returnValue, void 0);
      this.updateComplete.then(() => {
        this._elDialog?.showModal();
        lockBodyScrolling(this);
      });
    } else {
      __privateSet(this, _returnValue, __privateGet(this, _returnValue) || "prop-change");
      this._elDialog?.close(__privateGet(this, _returnValue));
      unlockBodyScrolling(this);
      this.requestUpdate("open");
    }
  }
};
_returnValue = new WeakMap();
_handleNativeClose = new WeakMap();
_dispatchCloseEvent = new WeakMap();
_dispatchShowEvent = new WeakMap();
_dispatchUiStateEvent = new WeakMap();
_handleTriggerSlotChange = new WeakSet();
handleTriggerSlotChange_fn = function() {
  if (this._elTriggerSlot && this._elTriggerSlot.assignedElements()[0]) {
    const trigger = this._elTriggerSlot.assignedElements()[0];
    trigger?.addEventListener("click", __privateGet(this, _handleTriggerClick));
    trigger?.setAttribute("aria-haspopup", "dialog");
  }
};
_handleTriggerClick = new WeakMap();
GdsDialog.styles = [styles];
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsDialog.prototype, "open", 2);
__decorateClass([
  property()
], GdsDialog.prototype, "heading", 2);
__decorateClass([
  property()
], GdsDialog.prototype, "variant", 2);
__decorateClass([
  query("dialog")
], GdsDialog.prototype, "_elDialog", 2);
__decorateClass([
  query('slot[name="trigger"]')
], GdsDialog.prototype, "_elTriggerSlot", 2);
__decorateClass([
  watch("open")
], GdsDialog.prototype, "_handleOpenChange", 1);
GdsDialog = __decorateClass([
  gdsCustomElement("gds-dialog", {
    dependsOn: [GdsButton, GdsCard, GdsFlex, IconCrossLarge]
  }),
  localized()
], GdsDialog);
export {
  GdsDialog
};
