import {
  __decorateClass
} from "../../../chunks/chunk.QTSIPXV3.js";
import { msg, str } from "@lit/localize";
import { css } from "lit";
import { when } from "lit/directives/when.js";
import { GdsElement } from "../../../gds-element.js";
import { gdsCustomElement, html } from "../../../scoping.js";
import { GdsCard } from "../../card/card.component.js";
import { GdsFlex } from "../../flex/flex.component.js";
import { GdsText } from "../../text/text.component.js";
let GdsFormSummary = class extends GdsElement {
  connectedCallback() {
    super.connectedCallback();
    this.form = this.closest("form") || void 0;
    if (this.form) {
      this.formObserver = new MutationObserver(() => {
        this.requestUpdate();
      });
      this.formObserver.observe(this.form, { attributes: true, subtree: true });
    }
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.formObserver?.disconnect();
  }
  render() {
    const formControlElements = Array.from(
      this.form?.elements || []
    );
    const errors = formControlElements.filter((e) => e.invalid);
    return when(
      errors.length > 0,
      () => html`<gds-card
          level="2"
          border="4xs"
          border-color="negative"
          border-radius="xs"
          padding="l"
          background="negative"
          color="negative"
        >
          <gds-flex gap="s">
            <gds-text font-size="heading-xs" font-weight="book">
              ${msg(
        str`There are ${errors.length} errors to correct before you can continue:`
      )}
            </gds-text>
            <ul>
              ${errors.map(
        (el) => html`<li>
                    <a
                      href=""
                      @click=${(e) => {
          e.preventDefault();
          el.focus();
        }}
                      >${el.label}</a
                    >
                  </li>`
      )}
            </ul>
          </gds-flex>
        </gds-card>`
    );
  }
};
GdsFormSummary.styles = css`
    ul {
      list-style-type: none;
      margin: 1rem 0 0;
      padding: 0;
    }
    li {
      margin: 0.5rem 0;
    }
    a {
      color: inherit;
    }
  `;
GdsFormSummary = __decorateClass([
  gdsCustomElement("gds-form-summary", {
    dependsOn: [GdsCard, GdsFlex, GdsText]
  })
], GdsFormSummary);
export {
  GdsFormSummary
};
