import { PropertyValues } from 'lit';
import { GdsFormattedText } from '../formatted-text';
import { DateTimeFormat } from './date-time-formatter';
/**
 * @element gds-formatted-date
 * @status beta
 *
 * `gds-formatted-date` extends `gds-text` and formats the date to the desired format.
 *
 * @example
 * <gds-formatted-date
 *   value="2023-10-10T12:00:00Z"
 *   locale="sv-SE"
 *   format="dateOnlyNumbers">
 * </gds-formatted-date>
 */
export declare class GdsFormattedDate extends GdsFormattedText {
    /** The date value to be formatted, either Date or ISO string. */
    value?: Date | string;
    /**
     * Specifies the date format.
     * @default 'dateOnlyNumbers'
     */
    format: DateTimeFormat;
    /** The locale used for date formatting. */
    locale?: string;
    get formattedValue(): string;
    protected firstUpdated(_changedProperties: PropertyValues): void;
}
