import { PropertyValues } from 'lit';
import { GdsFormattedText } from '../formatted-text';
import { NumberFormats } from '../formatters';
/**
 * @element gds-formatted-number
 * @status beta
 *
 * `gds-formatted-number` extends `gds-text` and formats the number to the desired format.
 *
 * @example
 * <gds-formatted-number
 *   value="1234.5"
 *   locale="sv-SE"
 *   currency="SEK">
 * </gds-formatted-number>
 */
export declare class GdsFormattedNumber extends GdsFormattedText {
    /** The numerical value to display. */
    value?: number | string;
    /** The locale used for number formatting. */
    locale?: string;
    /** The currency used when formatting numbers. */
    currency?: string;
    /**
     * Specifies the number format.
     * @default 'decimalsAndThousands'
     */
    protected format: NumberFormats;
    get formattedValue(): string;
    protected firstUpdated(_changedProperties: PropertyValues): void;
}
