import { GdsElement } from '../../gds-element';
declare const GdsIcon_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").MarginProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & typeof GdsElement;
/**
 * @element gds-icon
 * @status stable
 *
 * @part icon - The icon SVG element.
 */
export declare class GdsIcon extends GdsIcon_base {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * This property allow you to set the size of the icon with the token and custom values.
     * If not provided, uses the icon's default size.
     *
     * The size is a shorthand for setting both width and height at once.
     */
    size?: string;
    /**
     * This property allow you to set the width of the icon. If not provided, the default width is auto.
     *
     * @deprecated Use the `size` property instead.
     *
     * ```html
     * <gds-icon size="m"></gds-icon>
     * ```
     */
    width?: number;
    /**
     * This property allow you to set the height of the icon. If not provided, the default height is 1lh.
     *
     *@deprecated Use the `size` property instead.
     *
     * ```html
     * <gds-icon size="m"></gds-icon>
     * ```
     */
    height?: number;
    /**
     * When set to true, the solid version of the icon is displayed.
     * When set to false or not provided, the regular version of the icon is displayed.
     */
    solid: boolean;
    /**
     * When set to true, you can apply custom stroke width to the icon.
     */
    stroke?: number;
    /**
     * When viewbox is defined it will override the default viewbox of the icon.
     *
     * @deprecated this prop will be removed on the next major release
     *
     */
    box: boolean;
    /**
     * This property allow you to set the accessible label of the icon.
     * If not provided, the icon will be presentational.
     */
    label: string;
    protected static _name: string;
    protected static _regularSVG?: string;
    protected static _solidSVG?: string;
    protected static _width: number;
    protected static _height: number;
    protected static _viewBox: string;
    /**
     * Generates the SVG attributes for the icon
     * @private
     */
    private get svgAttributes();
    /**
     * Gets the appropriate SVG content based on the solid property
     * @private
     */
    private get svgContent();
    /**
     * Applies stroke width to SVG paths if stroke property is set
     * @private
     */
    private applyStroke;
    /**
     * Generates the SVG attributes string
     * @private
     */
    private generateAttributesString;
    render(): import("lit-html").TemplateResult<1>;
}
export {};
