import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { html } from "lit";
import { property } from "lit/decorators.js";
import { unsafeHTML } from "lit/directives/unsafe-html.js";
import { GdsElement } from "../../gds-element.js";
import { tokens } from "../../tokens.style.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import { forSpaceTokensAndCustomValues } from "../../utils/helpers/index.js";
import {
  withLayoutChildProps,
  withMarginProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import IconCSS from "./icon.style.js";
class GdsIcon extends withMarginProps(withLayoutChildProps(GdsElement)) {
  constructor() {
    super(...arguments);
    this.solid = false;
    this.box = false;
    this.label = "";
  }
  /**
   * Generates the SVG attributes for the icon
   * @private
   */
  get svgAttributes() {
    const constructor = this.constructor;
    const baseAttrs = {
      fill: "none",
      xmlns: "http://www.w3.org/2000/svg",
      // TODO: Remove in 2.0.0
      // (deprecated)
      ...this.size === void 0 && {
        width: this.width || constructor._width,
        height: this.width || constructor._height
      } || {},
      viewBox: this.box || constructor._viewBox,
      part: "icon"
    };
    if (this.label) {
      return {
        ...baseAttrs,
        "aria-label": this.label
      };
    } else {
      return {
        ...baseAttrs,
        role: "presentation"
      };
    }
  }
  /**
   * Gets the appropriate SVG content based on the solid property
   * @private
   */
  get svgContent() {
    const constructor = this.constructor;
    return this.solid ? constructor._solidSVG : constructor._regularSVG;
  }
  /**
   * Applies stroke width to SVG paths if stroke property is set
   * @private
   */
  applyStroke(content) {
    if (!this.stroke)
      return content;
    return content.replace(
      /<(path|rect|circle|ellipse|line|polyline|polygon)/g,
      `<$1 stroke-width="${this.stroke}"`
    );
  }
  /**
   * Generates the SVG attributes string
   * @private
   */
  generateAttributesString(attrs) {
    return Object.entries(attrs).filter(([_, value]) => value !== void 0).map(([key, value]) => `${key}="${value}"`).join("\n      ");
  }
  render() {
    const attrs = this.svgAttributes;
    let content = this.svgContent || "";
    if (this.stroke) {
      content = this.applyStroke(content);
    }
    const svg = `
      <svg ${this.generateAttributesString(attrs)}>
        ${content}
      </svg>
    `;
    return html`${unsafeHTML(svg)}`;
  }
}
GdsIcon.styles = [tokens, IconCSS];
__decorateClass([
  styleExpressionProperty({
    ...forSpaceTokensAndCustomValues,
    property: "height",
    selector: "svg"
  })
], GdsIcon.prototype, "size", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "width", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "height", 2);
__decorateClass([
  property({ type: Boolean })
], GdsIcon.prototype, "solid", 2);
__decorateClass([
  property({ type: Number })
], GdsIcon.prototype, "stroke", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "box", 2);
__decorateClass([
  property({ type: String })
], GdsIcon.prototype, "label", 2);
export {
  GdsIcon
};
