import { GdsButton } from '../button/button.component';
import { GdsFormControlElement } from '../form/form-control';
declare class Input extends GdsFormControlElement<string> {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The supporting text displayed between the label and the field.
     * This text provides additional context or information to the user.
     */
    supportingText: string;
    /**
     * Whether the supporting text should be displayed or not.
     */
    showExtendedSupportingText: boolean;
    /**
     * Whether the field should be clearable or not. Clearable fields will display a clear button when
     * the field has a value.
     */
    clearable: boolean;
    /**
     * The maximum number of characters allowed in the field.
     */
    maxlength: number;
    /**
     * Controls the font-size of texts and height of the field.
     */
    size: 'large' | 'small';
    /**
     * Hides the header and the footer, while still keeping the accessible label
     *
     * Always set the `label` attribute, and if you need to hide it, add this attribute and keep `label` set.
     */
    plain: boolean;
    private elInputAsync;
    private elInput;
    /**
     * A reference to the clear button element. Returns null if there is no clear button.
     * Intended for use in integration tests.
     */
    test_getClearButton(): GdsButton | null | undefined;
    /**
     * A reference to the field element. This does not refer to the input element itself,
     * but the wrapper that makes up the visual field.
     * Intended for use in integration tests.
     */
    test_getFieldElement(): Element | null | undefined;
    constructor();
    render(): any;
    _getValidityAnchor(): HTMLInputElement;
}
declare const GdsInput_base: (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").SizeXProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").MarginProps) & (new (...args: any[]) => import("../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & typeof Input;
/**
 * @summary A custom input element that can be used in forms.
 * @status beta
 *
 * @element gds-input
 *.
 * @slot lead - Accepts `gds-icon-[ICON_NAME]`. Use this to place an icon in the start of the field.
 * @slot trail - Accepts `gds-badge`. Use this to place a badge in the field, for displaying currency for example.
 * @slot extended-supporting-text - A longer supporting text can be placed here. It will be
 *       displayed in a panel when the user clicks the info button.
 * @event gds-input-cleared - Fired when the clear button is clicked.
 */
export declare class GdsInput extends GdsInput_base {
}
export {};
