import { GdsFormControlElement } from '../../form/form-control';
import type { GdsRadio } from '../radio';
declare class RadioGroup extends GdsFormControlElement<string> {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the font-size of label and supporting text on group form control header and single radio buttons respectively.
     */
    size: 'large' | 'small';
    /**
     * The direction in which radio buttons are displayed.
     */
    direction: 'row' | 'column';
    /**
     * The supporting text displayed between the label and the field.
     * This text provides additional context or information to the user.
     */
    supportingText: string;
    /**
     * Whether the supporting text should be displayed or not.
     */
    showExtendedSupportingText: boolean;
    /**
     * Returns an array of `<gds-radio>` elements in the radio group.
     *
     * @readonly
     */
    get radios(): GdsRadio[];
    private _contentElement;
    private _isConnected;
    connectedCallback(): void;
    disconnectedCallback(): void;
    protected _getValidityAnchor(): HTMLElement;
    private _handleValueChange;
    private _syncRadioStates;
    render(): any;
}
declare const GdsRadioGroup_base: (new (...args: any[]) => import("../../../utils/mixins/declarative-layout-mixins").LayoutChildProps) & (new (...args: any[]) => import("../../../utils/mixins/declarative-layout-mixins").MarginProps) & (new (...args: any[]) => import("../../../utils/mixins/declarative-layout-mixins").SizeXProps) & typeof RadioGroup;
/**
 * @summary A form control component for grouping radio buttons.
 * @status beta
 *
 * @element gds-radio-group
 *
 * @slot - Default slot for radio buttons (accepts `gds-radio` elements)
 * @slot extended-supporting-text - A longer supporting text that will be displayed in a panel when the user clicks the info button
 *
 * @event change - Fired when a radio button selection changes
 * @event input - Fired when a radio button selection changes
 */
export declare class GdsRadioGroup extends GdsRadioGroup_base {
}
export {};
