import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod,
  __privateSet
} from "../../chunks/chunk.QTSIPXV3.js";
var _getWrapperClasses, getWrapperClasses_fn, _originalStyles;
import { localized, msg } from "@lit/localize";
import { property, state } from "lit/decorators.js";
import { classMap } from "lit/directives/class-map.js";
import { when } from "lit/directives/when.js";
import { GdsElement } from "../../gds-element.js";
import { gdsCustomElement, html } from "../../scoping.js";
import { tokens } from "../../tokens.style.js";
import { watch } from "../../utils/decorators/watch.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withPositioningProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { styles } from "./spinner.styles.js";
let GdsSpinner = class extends withMarginProps(
  withPositioningProps(withLayoutChildProps(GdsElement))
) {
  constructor() {
    super(...arguments);
    /**
     * Generates CSS classes for the wrapper element based on component state
     * @private
     */
    __privateAdd(this, _getWrapperClasses);
    this.label = msg("Loading...");
    this.showLabel = false;
    this.cover = false;
    this.fullscreen = false;
    this.size = "md";
    this._isAnimating = false;
    /**
     * Stores original document styles before applying fullscreen mode
     * @private
     */
    __privateAdd(this, _originalStyles, {
      overflow: "visible",
      overscrollBehavior: "auto"
    });
  }
  /**
   * Sets up accessibility attributes and initializes the spinner
   */
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "status");
    this.setAttribute("aria-live", "polite");
    this._isAnimating = true;
    this.dispatchEvent(new CustomEvent("gds-spinner-connected"));
  }
  /**
   * Cleans up document styles if fullscreen mode was used
   */
  disconnectedCallback() {
    super.disconnectedCallback();
    if (this.fullscreen) {
      this.fullscreen = false;
      this._toggleRootStyles();
    }
    this._isAnimating = false;
    super.disconnectedCallback();
  }
  _updateAriaLabel() {
    this.setAttribute("aria-label", this.label);
  }
  /**
   * Renders the spinner component
   */
  render() {
    return html`
      <div part="wrapper" class=${classMap(__privateMethod(this, _getWrapperClasses, getWrapperClasses_fn).call(this))}>
        <span part="spinner" class="spinner"></span>
        ${when(
      this.label && this.showLabel,
      () => html`<span part="label" class="spinner-label">${this.label}</span>`,
      () => null
    )}
      </div>
    `;
  }
  _toggleRootStyles() {
    const { style } = document.documentElement;
    if (this.fullscreen) {
      __privateSet(this, _originalStyles, {
        overflow: style.overflow,
        overscrollBehavior: style.overscrollBehavior
      });
      style.overflow = "hidden";
      style.overscrollBehavior = "none";
    } else {
      style.overflow = __privateGet(this, _originalStyles).overflow;
      style.overscrollBehavior = __privateGet(this, _originalStyles).overscrollBehavior;
    }
  }
};
_getWrapperClasses = new WeakSet();
getWrapperClasses_fn = function() {
  return {
    "spinner-wrapper": true,
    "spinner-fullscreen": this.fullscreen,
    "spinner-cover": this.cover,
    "spinner-backdrop": this.cover || this.fullscreen,
    "spinner-animating": this._isAnimating
  };
};
_originalStyles = new WeakMap();
/** All styles are defined in the external styles file */
GdsSpinner.styles = [tokens, styles];
__decorateClass([
  property({ type: String })
], GdsSpinner.prototype, "label", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "showLabel", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "cover", 2);
__decorateClass([
  property({ type: Boolean, reflect: true })
], GdsSpinner.prototype, "fullscreen", 2);
__decorateClass([
  property({ type: String, reflect: true })
], GdsSpinner.prototype, "size", 2);
__decorateClass([
  state()
], GdsSpinner.prototype, "_isAnimating", 2);
__decorateClass([
  watch("label")
], GdsSpinner.prototype, "_updateAriaLabel", 1);
__decorateClass([
  watch("fullscreen")
], GdsSpinner.prototype, "_toggleRootStyles", 1);
GdsSpinner = __decorateClass([
  gdsCustomElement("gds-spinner"),
  localized()
], GdsSpinner);
export {
  GdsSpinner
};
