import { GdsDiv } from '../div/div.component';
/**
 * @element gds-text
 * @status beta
 *
 * `gds-text` extends `gds-div` and adds the ability to set an internal tag name, such as `h1`, `h2`, etc. It also adds line clamping and text decoration properties.
 *
 * Style expression properties apply to the outer element unless otherwise specified.
 */
export declare class GdsText extends GdsDiv {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * Controls the tag of the text.
     * Supports all valid HTML tags like h1, h2, h3, h4, h5, h6, p, span, etc.
     */
    tag: string;
    /**
     * Style Expression Property that controls the `font-size` property.
     * Supports all typography size tokens from the design system.
     */
    'font-size'?: string;
    /**
     * Style Expression Property that controls the `font-weight` property.
     * Supports all typography weight tokens from the design system.
     */
    'font-weight'?: string;
    /**
     * Controls the text-transform property of the text.
     * Supports all valid CSS text-transform values.
     */
    'text-transform'?: string;
    /**
     * Controls the text-decoration property of the inner element.
     * Supports all valid CSS text-decoration values.
     */
    'text-decoration'?: string;
    /**
     * Controls the number of lines it should show.
     */
    lines?: number;
    render(): import("lit-html").TemplateResult;
}
