import {
  __decorateClass,
  __privateAdd,
  __privateGet,
  __privateMethod
} from "../../chunks/chunk.QTSIPXV3.js";
var _shouldShowFooter, shouldShowFooter_fn, _forwardableAttrs, _handleOnInput, _handleOnChange, _handleOnPaste, _handleFieldClick, _handleClearBtnClick, _renderFieldContents, renderFieldContents_fn, _renderSlotLead, renderSlotLead_fn, _renderSlotTrail, renderSlotTrail_fn, _renderNativeTextarea, renderNativeTextarea_fn, _renderClearButton, renderClearButton_fn, _shouldShowRemainingChars, shouldShowRemainingChars_get;
import { localized, msg } from "@lit/localize";
import { property, query, queryAsync } from "lit/decorators.js";
import { when } from "lit/directives/when.js";
import { nothing } from "lit/html.js";
import { GdsFieldBase } from "../../primitives/field-base/field-base.component.js";
import { GdsFormControlFooter } from "../../primitives/form-control-footer/form-control-footer.component.js";
import { GdsFormControlHeader } from "../../primitives/form-control-header/form-control-header.component.js";
import { gdsCustomElement, html } from "../../scoping.js";
import formControlHostStyle from "../../shared-styles/form-control-host.style.js";
import { tokens } from "../../tokens.style.js";
import { watch } from "../../utils/decorators/index.js";
import { resizeObserver } from "../../utils/decorators/resize-observer.js";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import { forwardAttributes } from "../../utils/directives/index.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withSizeXProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import { GdsButton } from "../button/button.component.js";
import { GdsFormControlElement } from "../form/form-control.js";
import { IconCrossLarge } from "../icon/icons/cross-large.component.js";
import { styles } from "./textarea.styles.js";
let Textarea = class extends GdsFormControlElement {
  constructor() {
    super();
    __privateAdd(this, _shouldShowFooter);
    __privateAdd(this, _renderFieldContents);
    __privateAdd(this, _renderSlotLead);
    __privateAdd(this, _renderSlotTrail);
    __privateAdd(this, _renderNativeTextarea);
    __privateAdd(this, _renderClearButton);
    __privateAdd(this, _shouldShowRemainingChars);
    this._defaultRows = 4;
    this.rows = 4;
    this.supportingText = "";
    this.clearable = false;
    this.resizable = "auto";
    this.maxlength = Number.MAX_SAFE_INTEGER;
    this.size = "large";
    this.plain = false;
    this._handleSlotChange = () => {
      requestAnimationFrame(() => {
        this._handleResize();
      });
    };
    // Any attribute name added here will get forwarded to the native <input> element.
    __privateAdd(this, _forwardableAttrs, (attr) => ["type", "placeholder", "required"].includes(attr.name));
    __privateAdd(this, _handleOnInput, (e) => {
      const element = e.target;
      this.value = element.value;
    });
    __privateAdd(this, _handleOnChange, (e) => {
      const element = e.target;
      this.value = element.value;
      this.dispatchEvent(
        new Event("change", {
          bubbles: true,
          composed: true
        })
      );
    });
    __privateAdd(this, _handleOnPaste, (e) => {
      requestAnimationFrame(() => {
        this._setAutoHeight();
      });
    });
    __privateAdd(this, _handleFieldClick, () => {
      this.elTextareaAsync.then((el) => el.focus());
    });
    __privateAdd(this, _handleClearBtnClick, () => {
      this.value = "";
      this.elTextareaAsync.then((element) => {
        if (this.resizable === "manual") {
          element.style.height = "";
        } else if (this.resizable === "false") {
          const rowsToUse = this._initialRows ?? this._defaultRows;
          this.rows = rowsToUse;
          element.style.setProperty("--_lines", rowsToUse.toString());
        } else {
          const rowsToUse = this._initialRows ?? this._defaultRows;
          this.rows = rowsToUse;
          element.style.setProperty("--_lines", rowsToUse.toString());
          element.style.height = "";
        }
      });
      this.dispatchEvent(
        new Event("gds-input-cleared", {
          bubbles: true,
          composed: true
        })
      );
      this.dispatchEvent(
        new Event("input", {
          bubbles: true,
          composed: true
        })
      );
    });
    this.value = "";
  }
  /**
   * A reference to the clear button element. Returns null if there is no clear button.
   * Intended for use in integration tests.
   */
  test_getClearButton() {
    return this.shadowRoot?.querySelector("#clear-button");
  }
  /**
   * A reference to the field element. This does not refer to the input element itself,
   * but the wrapper that makes up the visual field.
   * Intended for use in integration tests.
   */
  test_getFieldElement() {
    return this.shadowRoot?.querySelector("#field");
  }
  _handleResize() {
    if (!this.fieldBase)
      return;
    Promise.resolve().then(() => {
      const fieldBaseShadowRoot = this.fieldBase?.shadowRoot;
      if (!fieldBaseShadowRoot)
        return;
      const rightDiv = fieldBaseShadowRoot.querySelector(
        ".right"
      );
      if (rightDiv) {
        const boundingBox = rightDiv.getBoundingClientRect();
        this.elTextarea.style.setProperty(
          "--padding-inline-end",
          `${boundingBox.width}px`
        );
      } else {
        this.elTextarea.style.removeProperty("--padding-inline-end");
      }
    });
  }
  connectedCallback() {
    super.connectedCallback();
    if (this.hasAttribute("rows")) {
      this._initialRows = this.rows;
    }
    this._setAutoHeight();
    this.addEventListener("slotchange", this._handleSlotChange);
  }
  disconnectedCallback() {
    super.disconnectedCallback();
    this.removeEventListener("slotchange", this._handleSlotChange);
  }
  render() {
    return html`
      ${when(
      !this.plain,
      () => html`<gds-form-control-header class="size-${this.size}">
            <label for="input" slot="label">${this.label}</label>
            <span slot="supporting-text" id="supporting-text">
              ${this.supportingText}
            </span>
            <slot
              name="extended-supporting-text"
              slot="extended-supporting-text"
            ></slot>
          </gds-form-control-header>`
    )}

      <gds-field-base
        id="field"
        .disabled=${this.disabled}
        .invalid=${this.invalid}
        @click=${__privateGet(this, _handleFieldClick)}
        multiline
      >
        ${__privateMethod(this, _renderFieldContents, renderFieldContents_fn).call(this)}
      </gds-field-base>

      ${when(
      __privateMethod(this, _shouldShowFooter, shouldShowFooter_fn).call(this),
      () => html`<gds-form-control-footer
            lass="size-${this.size}"
            .charCounter=${__privateGet(this, _shouldShowRemainingChars, shouldShowRemainingChars_get) && this.maxlength - (this.value?.length || 0)}
            .validationMessage=${this.invalid && (this.errorMessage || this.validationMessage)}
          ></gds-form-control-footer>`
    )}
    `;
  }
  _getValidityAnchor() {
    return this.elTextarea;
  }
  _setAutoHeight() {
    this.elTextareaAsync.then((element) => {
      if (this.resizable === "false") {
        const rowsToUse = this._initialRows ?? this._defaultRows;
        this.rows = rowsToUse;
        element.style.setProperty("--_lines", rowsToUse.toString());
        return;
      }
      if (this.resizable === "manual") {
        return;
      }
      if (this.resizable === "auto") {
        if (element.value === "") {
          const rowsToUse = this._initialRows ?? this._defaultRows;
          this.rows = rowsToUse;
          element.style.setProperty("--_lines", rowsToUse.toString());
        } else {
          const computedStyle = getComputedStyle(element);
          const lineHeight = parseFloat(computedStyle.lineHeight);
          const contentHeight = element.scrollHeight;
          const requiredRows = Math.ceil(contentHeight / lineHeight);
          const minRows = this._initialRows ?? this._defaultRows;
          this.rows = Math.max(minRows, requiredRows);
          element.style.setProperty("--_lines", this.rows.toString());
        }
      }
    });
  }
  _handleRowsChange() {
    if (this.hasAttribute("rows")) {
      this._initialRows = this.rows;
    }
    this.elTextareaAsync.then((element) => {
      if (this.resizable === "false") {
        element.style.setProperty("--_lines", this.rows.toString());
      }
    });
  }
};
_shouldShowFooter = new WeakSet();
shouldShowFooter_fn = function() {
  return !this.plain && (this.invalid || __privateGet(this, _shouldShowRemainingChars, shouldShowRemainingChars_get));
};
_forwardableAttrs = new WeakMap();
_handleOnInput = new WeakMap();
_handleOnChange = new WeakMap();
_handleOnPaste = new WeakMap();
_handleFieldClick = new WeakMap();
_handleClearBtnClick = new WeakMap();
_renderFieldContents = new WeakSet();
renderFieldContents_fn = function() {
  const elements = [
    __privateMethod(this, _renderSlotLead, renderSlotLead_fn).call(this),
    __privateMethod(this, _renderNativeTextarea, renderNativeTextarea_fn).call(this),
    __privateMethod(this, _renderClearButton, renderClearButton_fn).call(this),
    __privateMethod(this, _renderSlotTrail, renderSlotTrail_fn).call(this)
  ];
  return elements.map((element) => html`${element}`);
};
_renderSlotLead = new WeakSet();
renderSlotLead_fn = function() {
  return html`<slot slot="lead" name="lead"></slot>`;
};
_renderSlotTrail = new WeakSet();
renderSlotTrail_fn = function() {
  return html`<slot slot="trail" name="trail"></slot>`;
};
_renderNativeTextarea = new WeakSet();
renderNativeTextarea_fn = function() {
  return html`
      <textarea
        @input=${__privateGet(this, _handleOnInput)}
        @change=${__privateGet(this, _handleOnChange)}
        @paste=${__privateGet(this, _handleOnPaste)}
        .value=${this.value}
        id="input"
        class="native-control resize-${this.resizable}"
        aria-label=${this.plain && this.label || nothing}
        aria-describedby="supporting-text extended-supporting-text sub-label message"
        placeholder=" "
        ${forwardAttributes(__privateGet(this, _forwardableAttrs))}
      ></textarea>
    `;
};
_renderClearButton = new WeakSet();
renderClearButton_fn = function() {
  if (this.clearable && (this.value?.length || 0) > 0)
    return html`
        <gds-button
          size="small"
          rank="tertiary"
          variant="${this.invalid ? "negative" : ""}"
          ?disabled="${this.disabled}"
          label="${msg("Clear input")}"
          @click=${__privateGet(this, _handleClearBtnClick)}
          slot="action"
          id="clear-button"
        >
          <gds-icon-cross-large></gds-icon-cross-large>
        </gds-button>
      `;
  else
    return nothing;
};
_shouldShowRemainingChars = new WeakSet();
shouldShowRemainingChars_get = function() {
  return this.maxlength < Number.MAX_SAFE_INTEGER;
};
Textarea.styles = [tokens, formControlHostStyle, styles];
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => v,
    selector: "textarea",
    styleTemplate: (_prop, values) => {
      const ROWS = values[0];
      return `min-height: calc(1lh * ${ROWS});`;
    }
  })
], Textarea.prototype, "rows", 2);
__decorateClass([
  property({ attribute: "supporting-text" })
], Textarea.prototype, "supportingText", 2);
__decorateClass([
  property({ type: Boolean })
], Textarea.prototype, "clearable", 2);
__decorateClass([
  property({ type: String })
], Textarea.prototype, "resizable", 2);
__decorateClass([
  property({ type: Number })
], Textarea.prototype, "maxlength", 2);
__decorateClass([
  property({ type: String })
], Textarea.prototype, "size", 2);
__decorateClass([
  property({ type: Boolean })
], Textarea.prototype, "plain", 2);
__decorateClass([
  queryAsync("textarea")
], Textarea.prototype, "elTextareaAsync", 2);
__decorateClass([
  query("textarea")
], Textarea.prototype, "elTextarea", 2);
__decorateClass([
  query("gds-field-base")
], Textarea.prototype, "fieldBase", 2);
__decorateClass([
  resizeObserver()
], Textarea.prototype, "_handleResize", 1);
__decorateClass([
  watch("value")
], Textarea.prototype, "_setAutoHeight", 1);
__decorateClass([
  watch("rows")
], Textarea.prototype, "_handleRowsChange", 1);
Textarea = __decorateClass([
  localized()
], Textarea);
let GdsTextarea = class extends withLayoutChildProps(
  withSizeXProps(withMarginProps(Textarea))
) {
};
GdsTextarea = __decorateClass([
  gdsCustomElement("gds-textarea", {
    dependsOn: [
      GdsFormControlHeader,
      GdsFormControlFooter,
      GdsButton,
      GdsFieldBase,
      IconCrossLarge
    ]
  })
], GdsTextarea);
export {
  GdsTextarea
};
