import { GdsElement } from '../../gds-element';
export interface OptionsContainer extends HTMLElement {
    options: GdsOption[];
    multiple: boolean;
}
declare const GdsOption_base: (new (...args: any[]) => import("lit").LitElement) & typeof GdsElement;
/**
 * @element gds-option
 *
 * A listbox option is an option in a listbox widget.
 * This primitive corresponds to the aria `option` role: https://developer.mozilla.org/en-US/docs/Web/Accessibility/ARIA/Roles/option_role
 *
 * Can be used together with the `gds-listbox` primitive.
 *
 * @slot - The default slot. Custom content can be used to display the option.
 *
 * @event gds-select - Fired when the option is selected.
 * @event gds-blur - Fired when the option loses focus.
 * @event gds-focus - Fired when the option gains focus.
 */
export declare class GdsOption extends GdsOption_base {
    #private;
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The value of the option.
     */
    value: any;
    /**
     * Controls whether the option is visible or not.
     */
    get hidden(): boolean;
    set hidden(value: string | boolean);
    /**
     * Returns true if the option is selected.
     * Setting this property will select or unselect the option.
     */
    selected: boolean;
    /**
     * Sets this option as a placeholder.
     * A placehodler option does not have a value and will act as the default option.
     *
     * In a multiple select listbox, placeholder options will not be rendered in the list.
     */
    isPlaceholder: boolean;
    constructor();
    connectedCallback(): void;
    get parentElement(): OptionsContainer;
    private _handlePlaceholderStatusChange;
    render(): any;
}
export {};
