import { GdsElement } from '../../gds-element';
/**
 * @element gds-selection-field-label
 * @status beta
 * @internal
 *
 * A specialized label component designed for selection-based form controls (radio buttons and checkboxes).
 * It provides a consistent structure for:
 * - The control element (radio/checkbox)
 * - Primary label text
 * - Optional supporting text
 *
 * Usage:
 * ```html
 * <gds-selection-field-label
 *   label="Choose an option"
 *   supporting-text="Additional information"
 * >
 *   <slot><!-- radio/checkbox element goes here --></slot>
 * </gds-selection-field-label>
 * ```
 */
export declare class GdsSelectionFieldLabel extends GdsElement {
    static styles: (import("lit").CSSResult | import("lit").CSSResult[])[];
    /**
     * The main label text displayed next to the selection control
     */
    label: string;
    /**
     * Additional descriptive text displayed below the main label
     */
    supportingText: string;
    constructor();
    connectedCallback(): void;
    render(): any;
}
