import "../../chunks/chunk.QTSIPXV3.js";
import { unsafeCSS } from "lit";
import { property } from "lit/decorators.js";
import { parse, toCss, tokenize } from "../helpers/style-expression-parser.js";
const styleCache = /* @__PURE__ */ new Map();
function styleExpressionProperty(options) {
  return (proto, descriptor) => {
    const sel = options?.selector ?? String(":host");
    const prop = options?.property ?? String(descriptor);
    const valueTemplate = options?.valueTemplate;
    const styleTemplate = options?.styleTemplate;
    const cacheKey = options?.cacheOverrideKey ?? `0`;
    property({ attribute: options?.attribute, noAccessor: true })(
      proto,
      descriptor
    );
    Object.defineProperty(proto, descriptor, {
      get: function() {
        return this["__" + String(descriptor)];
      },
      set: async function(newValue) {
        if (!newValue)
          return;
        this["__" + String(descriptor)] = newValue;
        await this.updateComplete;
        const lvl = this.level ?? "0";
        const styleKey = sel + prop + newValue + lvl + cacheKey;
        if (styleCache.has(styleKey)) {
          ;
          this._dynamicStylesController.inject(
            `sep_${String(descriptor)}`,
            styleCache.get(styleKey)
          );
          return;
        }
        const ast = parse(tokenize(newValue));
        const css = toCss(
          sel,
          prop,
          ast,
          valueTemplate?.bind(this),
          styleTemplate?.bind(this)
        );
        const style = unsafeCSS(css);
        styleCache.set(styleKey, style);
        this._dynamicStylesController.inject(
          `sep_${String(descriptor)}`,
          style
        );
      }
    });
  };
}
export {
  styleExpressionProperty
};
